/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tySequence__mIo9bZUsotCEUUtEGNhYmaA tySequence__mIo9bZUsotCEUUtEGNhYmaA;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyObject_ERecoverableError__aRVEU9aWMU9b9a9baYZqUd3t9cA tyObject_ERecoverableError__aRVEU9aWMU9b9a9baYZqUd3t9cA;
typedef struct tyObject_ValueError__5lcTdgqMq62cNGRwBb0thA tyObject_ValueError__5lcTdgqMq62cNGRwBb0thA;
typedef struct tyObject_CatchableError__8K3kdpxrBD9aI27J0kpSCpQ tyObject_CatchableError__8K3kdpxrBD9aI27J0kpSCpQ;
typedef struct Exception Exception;
typedef struct RootObj RootObj;
typedef struct tySequence__QbmGqFaLnb1IWWToREeaIA tySequence__QbmGqFaLnb1IWWToREeaIA;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyObject_ESuggestDone__0sxcG9bses4KEF5Ub8L9ae1Q tyObject_ESuggestDone__0sxcG9bses4KEF5Ub8L9ae1Q;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA;
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU8 tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputs;
tySequence__mIo9bZUsotCEUUtEGNhYmaA* msgContext;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastError;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIndexTbl;
tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU8 tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef NU8 tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA[12];
typedef tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA tyArray__aKb7f3tXhAVVrqA9c1fkI9aQ[4];
typedef NimStringDesc* tyArray__kCuVL45VApJthfOamSfyoA[107];
struct RootObj {
TNimType* m_type;
};
struct Exception {
  RootObj Sup;
Exception* parent;
NCSTRING name;
NimStringDesc* message;
tySequence__QbmGqFaLnb1IWWToREeaIA* trace;
Exception* up;
};
struct tyObject_CatchableError__8K3kdpxrBD9aI27J0kpSCpQ {
  Exception Sup;
};
struct tyObject_ValueError__5lcTdgqMq62cNGRwBb0thA {
  tyObject_CatchableError__8K3kdpxrBD9aI27J0kpSCpQ Sup;
};
struct tyObject_ERecoverableError__aRVEU9aWMU9b9a9baYZqUd3t9cA {
  tyObject_ValueError__5lcTdgqMq62cNGRwBb0thA Sup;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
struct tyObject_ESuggestDone__0sxcG9bses4KEF5Ub8L9ae1Q {
  tyObject_ValueError__5lcTdgqMq62cNGRwBb0thA Sup;
};
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA {
NCSTRING procname;
NI line;
NCSTRING filename;
};
struct tySequence__mIo9bZUsotCEUUtEGNhYmaA {
  TGenericSeq Sup;
  tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w data[SEQ_DECL_SIZE];
};
struct tySequence__QbmGqFaLnb1IWWToREeaIA {
  TGenericSeq Sup;
  tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__mIo9bZUsotCEUUtEGNhYmaA)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__7lEisrXlQEzwtUKW5pzRCw)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__sM4lkSb7zS6F7OVMvW9cffQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__8rKxBHaz7QqNR9a4WIZqqqQ)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(void, initTable__lineinfos_327)(NI initialSize, tyObject_Table__9cHFtxtpgztIcDsypRz9byKw* Result);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___lineinfos_391)(tyObject_Table__9cHFtxtpgztIcDsypRz9byKw* t, NimStringDesc* key, NI32 val);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
static N_NIMCALL(void, Marker_tyRef__ZxmpRAoGpPEQ4O9aAddG2FQ)(void* p, NI op);
N_LIB_PRIVATE N_NOINLINE(void*, newObj)(TNimType* typ, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
static N_INLINE(void, decRef__system_5326)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5324)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5275)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5281)(void* usr);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5319)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
N_LIB_PRIVATE N_NIMCALL(void, raiseExceptionEx)(Exception* e, NCSTRING ename, NCSTRING procname, NCSTRING filename, NI line);
static N_NIMCALL(void, Marker_tyRef__NT9aUkpr32D3T9aXH5k1dBXg)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(NI, hash__lineinfos_236)(tyTuple__47w2DboNEPf69aPgubZdd7Q x);
N_LIB_PRIVATE TNimType NTImsgconfig__whxq1VkHUSUyso71rqeLKA_;
N_LIB_PRIVATE TNimType NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_;
extern TNimType NTIuint4954__M4na42GvebBMnI5wV9cYMxg_;
extern TNimType NTIint4954__kDPg4wXyR8DDyA0MeEjIsw_;
extern TNimType NTIint5150__sVg18TP9cLifHyygRe9cro9aA_;
extern TNimType NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_;
N_LIB_PRIVATE TNimType NTIterroroutput__AR9blT7YaZzdImck9a5cntbQ_;
N_LIB_PRIVATE TNimType NTIterroroutputs__do59a7ZIgkhUiYjsgmyMmFA_;
N_LIB_PRIVATE TNimType NTItupleLinfo58tlineinfo_detail58stringT__U3hs4iGgBd4Y9beL6zJV9boQ_;
extern TNimType NTIstring__77mFvmsOLKik79ci2hXkHEg_;
N_LIB_PRIVATE TNimType NTIseqLtupleLinfo58tlineinfo_detail58stringTT__mIo9bZUsotCEUUtEGNhYmaA_;
N_LIB_PRIVATE TNimType NTItable__9cHFtxtpgztIcDsypRz9byKw_;
N_LIB_PRIVATE TNimType NTIkeyvaluepair__xYhUhS7X82rKTqbT9bRfCnw_;
extern TNimType NTIint__rR5Bzr1D5krxoo1NcNyeMA_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__7lEisrXlQEzwtUKW5pzRCw_;
N_LIB_PRIVATE TNimType NTItfileinfo__2PBRRPxvvEH2sQ9cRi19bh7w_;
extern TNimType NTIrope__Ylz2qJFHq2oxQcAA5BJOQg_;
N_LIB_PRIVATE TNimType NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_;
N_LIB_PRIVATE TNimType NTIseqLtfileinfoT__8rKxBHaz7QqNR9a4WIZqqqQ_;
N_LIB_PRIVATE TNimType NTItmsgkind__rb52wmU1YxCKdMrEGfD9boA_;
N_LIB_PRIVATE TNimType NTItnotekinds__w2aCBEMcLy7t2KQe9caB9aBw_;
N_LIB_PRIVATE NIM_CONST tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw unknownLineInfo__lineinfos_284 = {((NU16) 0), ((NI16) -1), ((NI32) -1)}
;
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_14, "\?\?\?", 3);
N_LIB_PRIVATE NIM_CONST tyArray__aKb7f3tXhAVVrqA9c1fkI9aQ NotesVerbosity__lineinfos_194 = {{
0xff, 0xff, 0xff, 0x73, 0xfd, 0x75, 0x6f, 0xfc,
0x03, 0x07, 0x70, 0x00}
,
{
0xff, 0xff, 0xff, 0x73, 0xfd, 0x75, 0xef, 0xff,
0x47, 0x3f, 0x70, 0x00}
,
{
0xff, 0xff, 0xff, 0xff, 0xfd, 0x75, 0xef, 0xff,
0xf7, 0xff, 0x7d, 0x01}
,
{
0xff, 0xff, 0xff, 0xff, 0xff, 0x75, 0xef, 0xff,
0xff, 0xff, 0xff, 0x03}
}
;
N_LIB_PRIVATE TNimType NTItmsgkind__J0cVyqzpFKvufCivtQUgHQ_;
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_18, "unknown error", 13);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_19, "fatal error: $1", 15);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_20, "internal error: $1", 18);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_21, "illformed AST: $1", 17);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_22, "cannot open \'$1\'", 16);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_23, "\'$1\' expected", 13);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_24, "grid table is not implemented", 29);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_25, "illformed delimiter row of a markdown table", 43);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_26, "new section expected $1", 23);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_27, "general parse error", 19);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_28, "invalid directive: \'$1\'", 23);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_29, "invalid field: $1", 17);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_30, "number of footnotes and their references don\'t match: $1", 56);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_31, "disabled directive: \'$1\'", 24);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_32, "Cannot prove that \'$1\' is initialized.", 38);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_33, "$1", 2);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_34, "octal escape sequences do not exist; leading zero is ignored", 60);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_35, "\'$1\' is never read", 18);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_36, "\'$1\' might not have been initialized", 36);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_37, "config file \'$1\' is deprecated", 30);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_38, "\'l\' should not be used as an identifier; may look like \'1\' (one)", 64);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_39, "unknown magic \'$1\' might crash the compiler", 43);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_40, "redefinition of label \'$1\'", 26);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_41, "unknown substitution \'$1\'", 25);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_42, "broken link \'$1\'", 16);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_43, "language \'$1\' not supported", 27);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_44, "field \'$1\' not supported", 24);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_45, "RST style: $1", 13);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_46, "comment \'$1\' ignored", 20);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_47, "use {.base.} for base methods; baseless methods are deprecated", 62);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_48, "write to foreign heap", 21);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_49, "unsafe code: \'$1\'", 17);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_50, "imported and not used: \'$1\'", 27);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_51, "inherit from a more precise exception type like ValueError, IOError or OSError. If these don\'t suit, inherit from CatchableError or Defect.", 139);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_52, "each identifier is a tuple", 26);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_53, "setLen can potentially expand the sequence, but the element type \'$1\' doesn\'t have a valid default value", 104);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_54, "The \'$1\' type doesn\'t have a valid default value", 48);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_55, "Cannot prove that \'$1\' is initialized. This will become a compile time error in the future.", 91);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_56, "cannot prove that field \'$1\' is accessible", 42);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_57, "cannot prove index \'$1\' is valid", 32);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_58, "unreachable else, all cases are already covered", 47);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_59, "unreachable code after \'return\' statement or \'{.noReturn.}\' proc", 64);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_60, "not GC-safe: \'$1\'", 17);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_61, "use explicit initialization of \'$1\' for clarity", 47);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_62, "\'$1\' uses GC\'ed memory", 22);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_63, "usage of a type with a destructor in a non destructible context. This will become a compile time error in the future.", 117);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_64, "Special variable \'result\' is shadowed.", 38);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_65, "Number of spaces around \'$#\' is not consistent", 46);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_66, "Potential object case transition, instantiate new object instead", 64);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_67, "observable stores to \'$1\'", 25);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_68, "used \'result\' variable", 22);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_69, "cannot open: $1", 15);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_70, "file changed: $1", 16);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_71, "unsafe conversion to \'cstring\' from \'$1\'; this will become a compile time error in the future", 93);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_72, "operation successful: $#", 24);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_73, "$build\012$loc lines; ${sec}s; $mem; proj: $project; out: $output", 62);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_74, "CC: $1", 6);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_75, "line too long", 13);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_76, "\'$1\' is declared but not used", 29);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_77, "conversion to base object is not needed", 39);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_78, "conversion from $1 to itself is pointless", 41);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_79, "expression evaluates always to \'$1\'", 35);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_80, "quit() called", 13);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_81, "generated code listing:", 23);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_82, "end of listing", 14);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_83, "used config file \'$1\'", 21);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_84, "added path: \'$1\'", 16);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_85, "condition is always true: \'$1\'", 30);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_86, "condition is always false: \'$1\'", 31);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_87, "global variable declared here", 29);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_88, "expanded macro: $1", 18);
N_LIB_PRIVATE NIM_CONST tyArray__kCuVL45VApJthfOamSfyoA MsgKindToStr__lineinfos_120 = {((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_18),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_19),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_20),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_21),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_22),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_23),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_24),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_25),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_26),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_27),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_28),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_29),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_30),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_31),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_32),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_22),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_34),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_35),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_36),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_37),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_38),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_39),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_40),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_41),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_42),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_43),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_44),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_45),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_46),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_47),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_48),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_49),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_50),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_51),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_52),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_53),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_54),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_55),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_56),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_57),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_58),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_59),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_60),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_61),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_62),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_63),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_64),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_65),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_66),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_67),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_68),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_69),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_70),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_71),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_72),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_73),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_74),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_75),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_76),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_77),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_78),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_79),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_80),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_81),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_82),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_83),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_84),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_85),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_86),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_87),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_88),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33),
((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_33)}
;
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_89, "https://nim-lang.github.io/Nim", 30);
STRING_LITERAL(TM__eKG71Gy301SWgr9a6ccuVDg_90, "/", 1);
extern TNimType NTIvalueerror__5lcTdgqMq62cNGRwBb0thA_;
N_LIB_PRIVATE TNimType NTIerecoverableerror__aRVEU9aWMU9b9a9baYZqUd3t9cA_;
N_LIB_PRIVATE TNimType NTIreferecoverableerror__ZxmpRAoGpPEQ4O9aAddG2FQ_;
N_LIB_PRIVATE TNimType NTIesuggestdone__0sxcG9bses4KEF5Ub8L9ae1Q_;
N_LIB_PRIVATE TNimType NTIrefesuggestdone__NT9aUkpr32D3T9aXH5k1dBXg_;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5228;
static N_NIMCALL(void, Marker_tySequence__mIo9bZUsotCEUUtEGNhYmaA)(void* p, NI op) {
	tySequence__mIo9bZUsotCEUUtEGNhYmaA* a;
	NI T1_;
	a = (tySequence__mIo9bZUsotCEUUtEGNhYmaA*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field1, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__7lEisrXlQEzwtUKW5pzRCw)(void* p, NI op) {
	tySequence__7lEisrXlQEzwtUKW5pzRCw* a;
	NI T1_;
	a = (tySequence__7lEisrXlQEzwtUKW5pzRCw*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field1, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__sM4lkSb7zS6F7OVMvW9cffQ)(void* p, NI op) {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ* a;
	NI T1_;
	a = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_], op);
	}
}
static N_NIMCALL(void, Marker_tySequence__8rKxBHaz7QqNR9a4WIZqqqQ)(void* p, NI op) {
	tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* a;
	NI T1_;
	a = (tySequence__8rKxBHaz7QqNR9a4WIZqqqQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].fullPath, op);
	nimGCvisit((void*)a->data[T1_].projPath, op);
	nimGCvisit((void*)a->data[T1_].shortName, op);
	nimGCvisit((void*)a->data[T1_].quotedName, op);
	nimGCvisit((void*)a->data[T1_].quotedFullName, op);
	nimGCvisit((void*)a->data[T1_].lines, op);
	nimGCvisit((void*)a->data[T1_].dirtyFile, op);
	nimGCvisit((void*)a->data[T1_].hash, op);
	}
}
N_LIB_PRIVATE N_NIMCALL(void, initMsgConfig__lineinfos_321)(tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA* Result) {
	(*Result).trackPos.line = 0;
	(*Result).trackPos.col = 0;
	(*Result).trackPos.fileIndex = 0;
	(*Result).trackPosAttached = 0;
	(*Result).errorOutputs = 0;
	unsureAsgnRef((void**)&(*Result).msgContext, NIM_NIL);
	(*Result).lastError.line = 0;
	(*Result).lastError.col = 0;
	(*Result).lastError.fileIndex = 0;
	unsureAsgnRef((void**)&(*Result).filenameToIndexTbl.data, NIM_NIL);
	(*Result).filenameToIndexTbl.counter = 0;
	unsureAsgnRef((void**)&(*Result).fileInfos, NIM_NIL);
	(*Result).systemFileIdx = 0;
	unsureAsgnRef((void**) (&(*Result).msgContext), NIM_NIL);
	(*Result).lastError = unknownLineInfo__lineinfos_284;
	initTable__lineinfos_327(((NI) 32), (&(*Result).filenameToIndexTbl));
	unsureAsgnRef((void**) (&(*Result).fileInfos), NIM_NIL);
	(*Result).errorOutputs = 3;
	X5BX5Deq___lineinfos_391((&(*Result).filenameToIndexTbl), ((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_14), ((NI32) -1));
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, createDocLink__lineinfos_6)(NimStringDesc* urlSuffix) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = copyString(((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_89));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((NI) 0) < (urlSuffix ? urlSuffix->Sup.len : 0));
		if (!(T3_)) goto LA4_;
		T3_ = ((NU8)(urlSuffix->data[((NI) 0)]) == (NU8)(47));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = resizeString(result, (urlSuffix ? urlSuffix->Sup.len : 0) + 0);
appendString(result, urlSuffix);
	}
	goto LA1_;
	LA5_: ;
	{
		NimStringDesc* T8_;
		T8_ = NIM_NIL;
		T8_ = rawNewString((urlSuffix ? urlSuffix->Sup.len : 0) + 1);
appendString(T8_, ((NimStringDesc*) &TM__eKG71Gy301SWgr9a6ccuVDg_90));
appendString(T8_, urlSuffix);
		result = resizeString(result, (T8_ ? T8_->Sup.len : 0) + 0);
appendString(result, T8_);
	}
	LA1_: ;
	return result;
}
static N_NIMCALL(void, Marker_tyRef__ZxmpRAoGpPEQ4O9aAddG2FQ)(void* p, NI op) {
	tyObject_ERecoverableError__aRVEU9aWMU9b9a9baYZqUd3t9cA* a;
	a = (tyObject_ERecoverableError__aRVEU9aWMU9b9a9baYZqUd3t9cA*)p;
	nimGCvisit((void*)(*a).Sup.Sup.Sup.parent, op);
	nimGCvisit((void*)(*a).Sup.Sup.Sup.message, op);
	nimGCvisit((void*)(*a).Sup.Sup.Sup.trace, op);
	nimGCvisit((void*)(*a).Sup.Sup.Sup.up, op);
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5324)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5275((&gch__system_5228.zct), c);
}
static N_INLINE(void, decRef__system_5326)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5324(c);
	}
	LA4_: ;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5281)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T1_;
	T1_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = usrToCell__system_5281(p);
	decRef__system_5326(T1_);
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5319)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5281(src);
		incRef__system_5319(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5281((*dest));
		decRef__system_5326(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NOINLINE(void, raiseRecoverableError__lineinfos_262)(NimStringDesc* msg) {
	tyObject_ERecoverableError__aRVEU9aWMU9b9a9baYZqUd3t9cA* T1_;
	NimStringDesc* T2_;
	T1_ = NIM_NIL;
	T1_ = (tyObject_ERecoverableError__aRVEU9aWMU9b9a9baYZqUd3t9cA*) newObj((&NTIreferecoverableerror__ZxmpRAoGpPEQ4O9aAddG2FQ_), sizeof(tyObject_ERecoverableError__aRVEU9aWMU9b9a9baYZqUd3t9cA));
	(*T1_).Sup.Sup.Sup.Sup.m_type = (&NTIerecoverableerror__aRVEU9aWMU9b9a9baYZqUd3t9cA_);
	(*T1_).Sup.Sup.Sup.name = "ERecoverableError";
	T2_ = NIM_NIL;
	T2_ = (*T1_).Sup.Sup.Sup.message; (*T1_).Sup.Sup.Sup.message = copyStringRC1(msg);
	if (T2_) nimGCunrefNoCycle(T2_);
	asgnRef((void**) (&(*T1_).Sup.Sup.Sup.parent), ((Exception*) NIM_NIL));
	raiseExceptionEx((Exception*)T1_, "ERecoverableError", "raiseRecoverableError", "lineinfos.nim", 293);
}
static N_NIMCALL(void, Marker_tyRef__NT9aUkpr32D3T9aXH5k1dBXg)(void* p, NI op) {
	tyObject_ESuggestDone__0sxcG9bses4KEF5Ub8L9ae1Q* a;
	a = (tyObject_ESuggestDone__0sxcG9bses4KEF5Ub8L9ae1Q*)p;
	nimGCvisit((void*)(*a).Sup.Sup.Sup.parent, op);
	nimGCvisit((void*)(*a).Sup.Sup.Sup.message, op);
	nimGCvisit((void*)(*a).Sup.Sup.Sup.trace, op);
	nimGCvisit((void*)(*a).Sup.Sup.Sup.up, op);
}
N_LIB_PRIVATE N_NIMCALL(NI, hash__lineinfos_233)(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw i) {
	NI result;
	tyTuple__47w2DboNEPf69aPgubZdd7Q T1_;
	result = (NI)0;
	T1_.Field0 = ((NI) (i.line));
	T1_.Field1 = ((NI) (i.col));
	T1_.Field2 = ((NI) (i.fileIndex));
	result = hash__lineinfos_236(T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, atmlineinfosdotnim_DatInit000)(void) {
static TNimNode* TM__eKG71Gy301SWgr9a6ccuVDg_2_8[8];
static TNimNode* TM__eKG71Gy301SWgr9a6ccuVDg_3_3[3];
static TNimNode* TM__eKG71Gy301SWgr9a6ccuVDg_4_2[2];
NI TM__eKG71Gy301SWgr9a6ccuVDg_6;
static char* NIM_CONST TM__eKG71Gy301SWgr9a6ccuVDg_5[2] = {
"eStdOut", 
"eStdErr"};
static TNimNode* TM__eKG71Gy301SWgr9a6ccuVDg_7_2[2];
static TNimNode* TM__eKG71Gy301SWgr9a6ccuVDg_8_2[2];
static TNimNode* TM__eKG71Gy301SWgr9a6ccuVDg_9_3[3];
static TNimNode* TM__eKG71Gy301SWgr9a6ccuVDg_10_9[9];
static TNimNode* TM__eKG71Gy301SWgr9a6ccuVDg_11_107[107];
NI TM__eKG71Gy301SWgr9a6ccuVDg_13;
static char* NIM_CONST TM__eKG71Gy301SWgr9a6ccuVDg_12[107] = {
"errUnknown", 
"errFatal", 
"errInternal", 
"errIllFormedAstX", 
"errCannotOpenFile", 
"errXExpected", 
"errRstGridTableNotImplemented", 
"errRstMarkdownIllformedTable", 
"errRstNewSectionExpected", 
"errRstGeneralParseError", 
"errRstInvalidDirectiveX", 
"errRstInvalidField", 
"errRstFootnoteMismatch", 
"errRstSandboxedDirective", 
"errProveInit", 
"errGenerated", 
"errUser", 
"CannotOpenFile", 
"OctalEscape", 
"XIsNeverRead", 
"XmightNotBeenInit", 
"Deprecated", 
"ConfigDeprecated", 
"DotLikeOps", 
"SmallLshouldNotBeUsed", 
"UnknownMagic", 
"RedefinitionOfLabel", 
"UnknownSubstitutionX", 
"BrokenLink", 
"LanguageXNotSupported", 
"FieldXNotSupported", 
"warnRstStyle", 
"CommentXIgnored", 
"TypelessParam", 
"UseBase", 
"WriteToForeignHeap", 
"UnsafeCode", 
"UnusedImport", 
"InheritFromException", 
"EachIdentIsTuple", 
"UnsafeSetLen", 
"UnsafeDefault", 
"ProveInit", 
"ProveField", 
"ProveIndex", 
"UnreachableElse", 
"UnreachableCode", 
"IndexCheck", 
"GcUnsafe", 
"GcUnsafe2", 
"Uninit", 
"GcMem", 
"Destructor", 
"LockLevel", 
"ResultShadowed", 
"Spacing", 
"CaseTransition", 
"CycleCreated", 
"ObservableStores", 
"StrictNotNil", 
"ResultUsed", 
"CannotOpen", 
"FileChanged", 
"EnumConv", 
"AnyEnumConv", 
"HoleEnumConv", 
"CStringConv", 
"PtrToCstringConv", 
"Effect", 
"BareExcept", 
"CastSizes", 
"User", 
"Success", 
"SuccessX", 
"CC", 
"LineTooLong", 
"XDeclaredButNotUsed", 
"DuplicateModuleImport", 
"XCannotRaiseY", 
"ConvToBaseNotNeeded", 
"ConvFromXtoItselfNotNeeded", 
"ExprAlwaysX", 
"QuitCalled", 
"Processing", 
"ProcessingStmt", 
"CodeBegin", 
"CodeEnd", 
"Conf", 
"Path", 
"CondTrue", 
"CondFalse", 
"Name", 
"Pattern", 
"Exec", 
"Link", 
"Dependency", 
"Source", 
"Performance", 
"StackTrace", 
"GCStats", 
"GlobalVar", 
"ExpandMacro", 
"User", 
"UserRaw", 
"ExtendedContext", 
"MsgOrigin", 
"DeclaredLoc"};
static TNimNode* TM__eKG71Gy301SWgr9a6ccuVDg_15_107[107];
NI TM__eKG71Gy301SWgr9a6ccuVDg_17;
static char* NIM_CONST TM__eKG71Gy301SWgr9a6ccuVDg_16[107] = {
"errUnknown", 
"errFatal", 
"errInternal", 
"errIllFormedAstX", 
"errCannotOpenFile", 
"errXExpected", 
"errRstGridTableNotImplemented", 
"errRstMarkdownIllformedTable", 
"errRstNewSectionExpected", 
"errRstGeneralParseError", 
"errRstInvalidDirectiveX", 
"errRstInvalidField", 
"errRstFootnoteMismatch", 
"errRstSandboxedDirective", 
"errProveInit", 
"errGenerated", 
"errUser", 
"CannotOpenFile", 
"OctalEscape", 
"XIsNeverRead", 
"XmightNotBeenInit", 
"Deprecated", 
"ConfigDeprecated", 
"DotLikeOps", 
"SmallLshouldNotBeUsed", 
"UnknownMagic", 
"RedefinitionOfLabel", 
"UnknownSubstitutionX", 
"BrokenLink", 
"LanguageXNotSupported", 
"FieldXNotSupported", 
"warnRstStyle", 
"CommentXIgnored", 
"TypelessParam", 
"UseBase", 
"WriteToForeignHeap", 
"UnsafeCode", 
"UnusedImport", 
"InheritFromException", 
"EachIdentIsTuple", 
"UnsafeSetLen", 
"UnsafeDefault", 
"ProveInit", 
"ProveField", 
"ProveIndex", 
"UnreachableElse", 
"UnreachableCode", 
"IndexCheck", 
"GcUnsafe", 
"GcUnsafe2", 
"Uninit", 
"GcMem", 
"Destructor", 
"LockLevel", 
"ResultShadowed", 
"Spacing", 
"CaseTransition", 
"CycleCreated", 
"ObservableStores", 
"StrictNotNil", 
"ResultUsed", 
"CannotOpen", 
"FileChanged", 
"EnumConv", 
"AnyEnumConv", 
"HoleEnumConv", 
"CStringConv", 
"PtrToCstringConv", 
"Effect", 
"BareExcept", 
"CastSizes", 
"User", 
"Success", 
"SuccessX", 
"CC", 
"LineTooLong", 
"XDeclaredButNotUsed", 
"DuplicateModuleImport", 
"XCannotRaiseY", 
"ConvToBaseNotNeeded", 
"ConvFromXtoItselfNotNeeded", 
"ExprAlwaysX", 
"QuitCalled", 
"Processing", 
"ProcessingStmt", 
"CodeBegin", 
"CodeEnd", 
"Conf", 
"Path", 
"CondTrue", 
"CondFalse", 
"Name", 
"Pattern", 
"Exec", 
"Link", 
"Dependency", 
"Source", 
"Performance", 
"StackTrace", 
"GCStats", 
"GlobalVar", 
"ExpandMacro", 
"User", 
"UserRaw", 
"ExtendedContext", 
"MsgOrigin", 
"DeclaredLoc"};
static TNimNode TM__eKG71Gy301SWgr9a6ccuVDg_0[256];
NTImsgconfig__whxq1VkHUSUyso71rqeLKA_.size = sizeof(tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA);
NTImsgconfig__whxq1VkHUSUyso71rqeLKA_.align = NIM_ALIGNOF(tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA);
NTImsgconfig__whxq1VkHUSUyso71rqeLKA_.kind = 18;
NTImsgconfig__whxq1VkHUSUyso71rqeLKA_.base = 0;
NTImsgconfig__whxq1VkHUSUyso71rqeLKA_.flags = 2;
TM__eKG71Gy301SWgr9a6ccuVDg_2_8[0] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[1];
NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_.size = sizeof(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw);
NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_.align = NIM_ALIGNOF(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw);
NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_.kind = 18;
NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_.base = 0;
NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_.flags = 3;
TM__eKG71Gy301SWgr9a6ccuVDg_3_3[0] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[3];
TM__eKG71Gy301SWgr9a6ccuVDg_0[3].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[3].offset = offsetof(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw, line);
TM__eKG71Gy301SWgr9a6ccuVDg_0[3].typ = (&NTIuint4954__M4na42GvebBMnI5wV9cYMxg_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[3].name = "line";
TM__eKG71Gy301SWgr9a6ccuVDg_3_3[1] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[4];
TM__eKG71Gy301SWgr9a6ccuVDg_0[4].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[4].offset = offsetof(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw, col);
TM__eKG71Gy301SWgr9a6ccuVDg_0[4].typ = (&NTIint4954__kDPg4wXyR8DDyA0MeEjIsw_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[4].name = "col";
TM__eKG71Gy301SWgr9a6ccuVDg_3_3[2] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[5];
TM__eKG71Gy301SWgr9a6ccuVDg_0[5].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[5].offset = offsetof(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw, fileIndex);
TM__eKG71Gy301SWgr9a6ccuVDg_0[5].typ = (&NTIint5150__sVg18TP9cLifHyygRe9cro9aA_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[5].name = "fileIndex";
TM__eKG71Gy301SWgr9a6ccuVDg_0[2].len = 3; TM__eKG71Gy301SWgr9a6ccuVDg_0[2].kind = 2; TM__eKG71Gy301SWgr9a6ccuVDg_0[2].sons = &TM__eKG71Gy301SWgr9a6ccuVDg_3_3[0];
NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_.node = &TM__eKG71Gy301SWgr9a6ccuVDg_0[2];
TM__eKG71Gy301SWgr9a6ccuVDg_0[1].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[1].offset = offsetof(tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA, trackPos);
TM__eKG71Gy301SWgr9a6ccuVDg_0[1].typ = (&NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[1].name = "trackPos";
TM__eKG71Gy301SWgr9a6ccuVDg_2_8[1] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[6];
TM__eKG71Gy301SWgr9a6ccuVDg_0[6].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[6].offset = offsetof(tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA, trackPosAttached);
TM__eKG71Gy301SWgr9a6ccuVDg_0[6].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[6].name = "trackPosAttached";
TM__eKG71Gy301SWgr9a6ccuVDg_2_8[2] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[7];
NTIterroroutput__AR9blT7YaZzdImck9a5cntbQ_.size = sizeof(tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ);
NTIterroroutput__AR9blT7YaZzdImck9a5cntbQ_.align = NIM_ALIGNOF(tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ);
NTIterroroutput__AR9blT7YaZzdImck9a5cntbQ_.kind = 14;
NTIterroroutput__AR9blT7YaZzdImck9a5cntbQ_.base = 0;
NTIterroroutput__AR9blT7YaZzdImck9a5cntbQ_.flags = 3;
for (TM__eKG71Gy301SWgr9a6ccuVDg_6 = 0; TM__eKG71Gy301SWgr9a6ccuVDg_6 < 2; TM__eKG71Gy301SWgr9a6ccuVDg_6++) {
TM__eKG71Gy301SWgr9a6ccuVDg_0[TM__eKG71Gy301SWgr9a6ccuVDg_6+8].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[TM__eKG71Gy301SWgr9a6ccuVDg_6+8].offset = TM__eKG71Gy301SWgr9a6ccuVDg_6;
TM__eKG71Gy301SWgr9a6ccuVDg_0[TM__eKG71Gy301SWgr9a6ccuVDg_6+8].name = TM__eKG71Gy301SWgr9a6ccuVDg_5[TM__eKG71Gy301SWgr9a6ccuVDg_6];
TM__eKG71Gy301SWgr9a6ccuVDg_4_2[TM__eKG71Gy301SWgr9a6ccuVDg_6] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[TM__eKG71Gy301SWgr9a6ccuVDg_6+8];
}
TM__eKG71Gy301SWgr9a6ccuVDg_0[10].len = 2; TM__eKG71Gy301SWgr9a6ccuVDg_0[10].kind = 2; TM__eKG71Gy301SWgr9a6ccuVDg_0[10].sons = &TM__eKG71Gy301SWgr9a6ccuVDg_4_2[0];
NTIterroroutput__AR9blT7YaZzdImck9a5cntbQ_.node = &TM__eKG71Gy301SWgr9a6ccuVDg_0[10];
NTIterroroutputs__do59a7ZIgkhUiYjsgmyMmFA_.size = sizeof(tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ);
NTIterroroutputs__do59a7ZIgkhUiYjsgmyMmFA_.align = NIM_ALIGNOF(tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ);
NTIterroroutputs__do59a7ZIgkhUiYjsgmyMmFA_.kind = 19;
NTIterroroutputs__do59a7ZIgkhUiYjsgmyMmFA_.base = (&NTIterroroutput__AR9blT7YaZzdImck9a5cntbQ_);
NTIterroroutputs__do59a7ZIgkhUiYjsgmyMmFA_.flags = 3;
TM__eKG71Gy301SWgr9a6ccuVDg_0[11].len = 0; TM__eKG71Gy301SWgr9a6ccuVDg_0[11].kind = 0;
NTIterroroutputs__do59a7ZIgkhUiYjsgmyMmFA_.node = &TM__eKG71Gy301SWgr9a6ccuVDg_0[11];
TM__eKG71Gy301SWgr9a6ccuVDg_0[7].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[7].offset = offsetof(tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA, errorOutputs);
TM__eKG71Gy301SWgr9a6ccuVDg_0[7].typ = (&NTIterroroutputs__do59a7ZIgkhUiYjsgmyMmFA_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[7].name = "errorOutputs";
TM__eKG71Gy301SWgr9a6ccuVDg_2_8[3] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[12];
NTItupleLinfo58tlineinfo_detail58stringT__U3hs4iGgBd4Y9beL6zJV9boQ_.size = sizeof(tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ);
NTItupleLinfo58tlineinfo_detail58stringT__U3hs4iGgBd4Y9beL6zJV9boQ_.align = NIM_ALIGNOF(tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ);
NTItupleLinfo58tlineinfo_detail58stringT__U3hs4iGgBd4Y9beL6zJV9boQ_.kind = 18;
NTItupleLinfo58tlineinfo_detail58stringT__U3hs4iGgBd4Y9beL6zJV9boQ_.base = 0;
NTItupleLinfo58tlineinfo_detail58stringT__U3hs4iGgBd4Y9beL6zJV9boQ_.flags = 2;
TM__eKG71Gy301SWgr9a6ccuVDg_7_2[0] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[14];
TM__eKG71Gy301SWgr9a6ccuVDg_0[14].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[14].offset = offsetof(tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ, Field0);
TM__eKG71Gy301SWgr9a6ccuVDg_0[14].typ = (&NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[14].name = "Field0";
TM__eKG71Gy301SWgr9a6ccuVDg_7_2[1] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[15];
TM__eKG71Gy301SWgr9a6ccuVDg_0[15].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[15].offset = offsetof(tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ, Field1);
TM__eKG71Gy301SWgr9a6ccuVDg_0[15].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[15].name = "Field1";
TM__eKG71Gy301SWgr9a6ccuVDg_0[13].len = 2; TM__eKG71Gy301SWgr9a6ccuVDg_0[13].kind = 2; TM__eKG71Gy301SWgr9a6ccuVDg_0[13].sons = &TM__eKG71Gy301SWgr9a6ccuVDg_7_2[0];
NTItupleLinfo58tlineinfo_detail58stringT__U3hs4iGgBd4Y9beL6zJV9boQ_.node = &TM__eKG71Gy301SWgr9a6ccuVDg_0[13];
NTIseqLtupleLinfo58tlineinfo_detail58stringTT__mIo9bZUsotCEUUtEGNhYmaA_.size = sizeof(tySequence__mIo9bZUsotCEUUtEGNhYmaA*);
NTIseqLtupleLinfo58tlineinfo_detail58stringTT__mIo9bZUsotCEUUtEGNhYmaA_.align = NIM_ALIGNOF(tySequence__mIo9bZUsotCEUUtEGNhYmaA*);
NTIseqLtupleLinfo58tlineinfo_detail58stringTT__mIo9bZUsotCEUUtEGNhYmaA_.kind = 24;
NTIseqLtupleLinfo58tlineinfo_detail58stringTT__mIo9bZUsotCEUUtEGNhYmaA_.base = (&NTItupleLinfo58tlineinfo_detail58stringT__U3hs4iGgBd4Y9beL6zJV9boQ_);
NTIseqLtupleLinfo58tlineinfo_detail58stringTT__mIo9bZUsotCEUUtEGNhYmaA_.flags = 2;
NTIseqLtupleLinfo58tlineinfo_detail58stringTT__mIo9bZUsotCEUUtEGNhYmaA_.marker = Marker_tySequence__mIo9bZUsotCEUUtEGNhYmaA;
TM__eKG71Gy301SWgr9a6ccuVDg_0[12].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[12].offset = offsetof(tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA, msgContext);
TM__eKG71Gy301SWgr9a6ccuVDg_0[12].typ = (&NTIseqLtupleLinfo58tlineinfo_detail58stringTT__mIo9bZUsotCEUUtEGNhYmaA_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[12].name = "msgContext";
TM__eKG71Gy301SWgr9a6ccuVDg_2_8[4] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[16];
TM__eKG71Gy301SWgr9a6ccuVDg_0[16].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[16].offset = offsetof(tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA, lastError);
TM__eKG71Gy301SWgr9a6ccuVDg_0[16].typ = (&NTItlineinfo__66OQV9bsmGEfS6hVHBswcPw_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[16].name = "lastError";
TM__eKG71Gy301SWgr9a6ccuVDg_2_8[5] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[17];
NTItable__9cHFtxtpgztIcDsypRz9byKw_.size = sizeof(tyObject_Table__9cHFtxtpgztIcDsypRz9byKw);
NTItable__9cHFtxtpgztIcDsypRz9byKw_.align = NIM_ALIGNOF(tyObject_Table__9cHFtxtpgztIcDsypRz9byKw);
NTItable__9cHFtxtpgztIcDsypRz9byKw_.kind = 18;
NTItable__9cHFtxtpgztIcDsypRz9byKw_.base = 0;
NTItable__9cHFtxtpgztIcDsypRz9byKw_.flags = 2;
TM__eKG71Gy301SWgr9a6ccuVDg_8_2[0] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[19];
NTIkeyvaluepair__xYhUhS7X82rKTqbT9bRfCnw_.size = sizeof(tyTuple__xYhUhS7X82rKTqbT9bRfCnw);
NTIkeyvaluepair__xYhUhS7X82rKTqbT9bRfCnw_.align = NIM_ALIGNOF(tyTuple__xYhUhS7X82rKTqbT9bRfCnw);
NTIkeyvaluepair__xYhUhS7X82rKTqbT9bRfCnw_.kind = 18;
NTIkeyvaluepair__xYhUhS7X82rKTqbT9bRfCnw_.base = 0;
NTIkeyvaluepair__xYhUhS7X82rKTqbT9bRfCnw_.flags = 2;
TM__eKG71Gy301SWgr9a6ccuVDg_9_3[0] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[21];
TM__eKG71Gy301SWgr9a6ccuVDg_0[21].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[21].offset = offsetof(tyTuple__xYhUhS7X82rKTqbT9bRfCnw, Field0);
TM__eKG71Gy301SWgr9a6ccuVDg_0[21].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[21].name = "Field0";
TM__eKG71Gy301SWgr9a6ccuVDg_9_3[1] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[22];
TM__eKG71Gy301SWgr9a6ccuVDg_0[22].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[22].offset = offsetof(tyTuple__xYhUhS7X82rKTqbT9bRfCnw, Field1);
TM__eKG71Gy301SWgr9a6ccuVDg_0[22].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[22].name = "Field1";
TM__eKG71Gy301SWgr9a6ccuVDg_9_3[2] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[23];
TM__eKG71Gy301SWgr9a6ccuVDg_0[23].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[23].offset = offsetof(tyTuple__xYhUhS7X82rKTqbT9bRfCnw, Field2);
TM__eKG71Gy301SWgr9a6ccuVDg_0[23].typ = (&NTIint5150__sVg18TP9cLifHyygRe9cro9aA_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[23].name = "Field2";
TM__eKG71Gy301SWgr9a6ccuVDg_0[20].len = 3; TM__eKG71Gy301SWgr9a6ccuVDg_0[20].kind = 2; TM__eKG71Gy301SWgr9a6ccuVDg_0[20].sons = &TM__eKG71Gy301SWgr9a6ccuVDg_9_3[0];
NTIkeyvaluepair__xYhUhS7X82rKTqbT9bRfCnw_.node = &TM__eKG71Gy301SWgr9a6ccuVDg_0[20];
NTIkeyvaluepairseq__7lEisrXlQEzwtUKW5pzRCw_.size = sizeof(tySequence__7lEisrXlQEzwtUKW5pzRCw*);
NTIkeyvaluepairseq__7lEisrXlQEzwtUKW5pzRCw_.align = NIM_ALIGNOF(tySequence__7lEisrXlQEzwtUKW5pzRCw*);
NTIkeyvaluepairseq__7lEisrXlQEzwtUKW5pzRCw_.kind = 24;
NTIkeyvaluepairseq__7lEisrXlQEzwtUKW5pzRCw_.base = (&NTIkeyvaluepair__xYhUhS7X82rKTqbT9bRfCnw_);
NTIkeyvaluepairseq__7lEisrXlQEzwtUKW5pzRCw_.flags = 2;
NTIkeyvaluepairseq__7lEisrXlQEzwtUKW5pzRCw_.marker = Marker_tySequence__7lEisrXlQEzwtUKW5pzRCw;
TM__eKG71Gy301SWgr9a6ccuVDg_0[19].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[19].offset = offsetof(tyObject_Table__9cHFtxtpgztIcDsypRz9byKw, data);
TM__eKG71Gy301SWgr9a6ccuVDg_0[19].typ = (&NTIkeyvaluepairseq__7lEisrXlQEzwtUKW5pzRCw_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[19].name = "data";
TM__eKG71Gy301SWgr9a6ccuVDg_8_2[1] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[24];
TM__eKG71Gy301SWgr9a6ccuVDg_0[24].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[24].offset = offsetof(tyObject_Table__9cHFtxtpgztIcDsypRz9byKw, counter);
TM__eKG71Gy301SWgr9a6ccuVDg_0[24].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[24].name = "counter";
TM__eKG71Gy301SWgr9a6ccuVDg_0[18].len = 2; TM__eKG71Gy301SWgr9a6ccuVDg_0[18].kind = 2; TM__eKG71Gy301SWgr9a6ccuVDg_0[18].sons = &TM__eKG71Gy301SWgr9a6ccuVDg_8_2[0];
NTItable__9cHFtxtpgztIcDsypRz9byKw_.node = &TM__eKG71Gy301SWgr9a6ccuVDg_0[18];
TM__eKG71Gy301SWgr9a6ccuVDg_0[17].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[17].offset = offsetof(tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA, filenameToIndexTbl);
TM__eKG71Gy301SWgr9a6ccuVDg_0[17].typ = (&NTItable__9cHFtxtpgztIcDsypRz9byKw_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[17].name = "filenameToIndexTbl";
TM__eKG71Gy301SWgr9a6ccuVDg_2_8[6] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[25];
NTItfileinfo__2PBRRPxvvEH2sQ9cRi19bh7w_.size = sizeof(tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w);
NTItfileinfo__2PBRRPxvvEH2sQ9cRi19bh7w_.align = NIM_ALIGNOF(tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w);
NTItfileinfo__2PBRRPxvvEH2sQ9cRi19bh7w_.kind = 18;
NTItfileinfo__2PBRRPxvvEH2sQ9cRi19bh7w_.base = 0;
NTItfileinfo__2PBRRPxvvEH2sQ9cRi19bh7w_.flags = 2;
TM__eKG71Gy301SWgr9a6ccuVDg_10_9[0] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[27];
TM__eKG71Gy301SWgr9a6ccuVDg_0[27].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[27].offset = offsetof(tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w, fullPath);
TM__eKG71Gy301SWgr9a6ccuVDg_0[27].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[27].name = "fullPath";
TM__eKG71Gy301SWgr9a6ccuVDg_10_9[1] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[28];
TM__eKG71Gy301SWgr9a6ccuVDg_0[28].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[28].offset = offsetof(tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w, projPath);
TM__eKG71Gy301SWgr9a6ccuVDg_0[28].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[28].name = "projPath";
TM__eKG71Gy301SWgr9a6ccuVDg_10_9[2] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[29];
TM__eKG71Gy301SWgr9a6ccuVDg_0[29].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[29].offset = offsetof(tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w, shortName);
TM__eKG71Gy301SWgr9a6ccuVDg_0[29].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[29].name = "shortName";
TM__eKG71Gy301SWgr9a6ccuVDg_10_9[3] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[30];
TM__eKG71Gy301SWgr9a6ccuVDg_0[30].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[30].offset = offsetof(tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w, quotedName);
TM__eKG71Gy301SWgr9a6ccuVDg_0[30].typ = (&NTIrope__Ylz2qJFHq2oxQcAA5BJOQg_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[30].name = "quotedName";
TM__eKG71Gy301SWgr9a6ccuVDg_10_9[4] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[31];
TM__eKG71Gy301SWgr9a6ccuVDg_0[31].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[31].offset = offsetof(tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w, quotedFullName);
TM__eKG71Gy301SWgr9a6ccuVDg_0[31].typ = (&NTIrope__Ylz2qJFHq2oxQcAA5BJOQg_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[31].name = "quotedFullName";
TM__eKG71Gy301SWgr9a6ccuVDg_10_9[5] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[32];
NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_.size = sizeof(tySequence__sM4lkSb7zS6F7OVMvW9cffQ*);
NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_.align = NIM_ALIGNOF(tySequence__sM4lkSb7zS6F7OVMvW9cffQ*);
NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_.kind = 24;
NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_.base = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_.flags = 2;
NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_.marker = Marker_tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
TM__eKG71Gy301SWgr9a6ccuVDg_0[32].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[32].offset = offsetof(tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w, lines);
TM__eKG71Gy301SWgr9a6ccuVDg_0[32].typ = (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[32].name = "lines";
TM__eKG71Gy301SWgr9a6ccuVDg_10_9[6] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[33];
TM__eKG71Gy301SWgr9a6ccuVDg_0[33].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[33].offset = offsetof(tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w, dirtyFile);
TM__eKG71Gy301SWgr9a6ccuVDg_0[33].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[33].name = "dirtyFile";
TM__eKG71Gy301SWgr9a6ccuVDg_10_9[7] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[34];
TM__eKG71Gy301SWgr9a6ccuVDg_0[34].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[34].offset = offsetof(tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w, hash);
TM__eKG71Gy301SWgr9a6ccuVDg_0[34].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[34].name = "hash";
TM__eKG71Gy301SWgr9a6ccuVDg_10_9[8] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[35];
TM__eKG71Gy301SWgr9a6ccuVDg_0[35].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[35].offset = offsetof(tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w, dirty);
TM__eKG71Gy301SWgr9a6ccuVDg_0[35].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[35].name = "dirty";
TM__eKG71Gy301SWgr9a6ccuVDg_0[26].len = 9; TM__eKG71Gy301SWgr9a6ccuVDg_0[26].kind = 2; TM__eKG71Gy301SWgr9a6ccuVDg_0[26].sons = &TM__eKG71Gy301SWgr9a6ccuVDg_10_9[0];
NTItfileinfo__2PBRRPxvvEH2sQ9cRi19bh7w_.node = &TM__eKG71Gy301SWgr9a6ccuVDg_0[26];
NTIseqLtfileinfoT__8rKxBHaz7QqNR9a4WIZqqqQ_.size = sizeof(tySequence__8rKxBHaz7QqNR9a4WIZqqqQ*);
NTIseqLtfileinfoT__8rKxBHaz7QqNR9a4WIZqqqQ_.align = NIM_ALIGNOF(tySequence__8rKxBHaz7QqNR9a4WIZqqqQ*);
NTIseqLtfileinfoT__8rKxBHaz7QqNR9a4WIZqqqQ_.kind = 24;
NTIseqLtfileinfoT__8rKxBHaz7QqNR9a4WIZqqqQ_.base = (&NTItfileinfo__2PBRRPxvvEH2sQ9cRi19bh7w_);
NTIseqLtfileinfoT__8rKxBHaz7QqNR9a4WIZqqqQ_.flags = 2;
NTIseqLtfileinfoT__8rKxBHaz7QqNR9a4WIZqqqQ_.marker = Marker_tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
TM__eKG71Gy301SWgr9a6ccuVDg_0[25].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[25].offset = offsetof(tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA, fileInfos);
TM__eKG71Gy301SWgr9a6ccuVDg_0[25].typ = (&NTIseqLtfileinfoT__8rKxBHaz7QqNR9a4WIZqqqQ_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[25].name = "fileInfos";
TM__eKG71Gy301SWgr9a6ccuVDg_2_8[7] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[36];
TM__eKG71Gy301SWgr9a6ccuVDg_0[36].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[36].offset = offsetof(tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA, systemFileIdx);
TM__eKG71Gy301SWgr9a6ccuVDg_0[36].typ = (&NTIint5150__sVg18TP9cLifHyygRe9cro9aA_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[36].name = "systemFileIdx";
TM__eKG71Gy301SWgr9a6ccuVDg_0[0].len = 8; TM__eKG71Gy301SWgr9a6ccuVDg_0[0].kind = 2; TM__eKG71Gy301SWgr9a6ccuVDg_0[0].sons = &TM__eKG71Gy301SWgr9a6ccuVDg_2_8[0];
NTImsgconfig__whxq1VkHUSUyso71rqeLKA_.node = &TM__eKG71Gy301SWgr9a6ccuVDg_0[0];
NTItmsgkind__rb52wmU1YxCKdMrEGfD9boA_.size = sizeof(tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ);
NTItmsgkind__rb52wmU1YxCKdMrEGfD9boA_.align = NIM_ALIGNOF(tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ);
NTItmsgkind__rb52wmU1YxCKdMrEGfD9boA_.kind = 14;
NTItmsgkind__rb52wmU1YxCKdMrEGfD9boA_.base = 0;
NTItmsgkind__rb52wmU1YxCKdMrEGfD9boA_.flags = 3;
for (TM__eKG71Gy301SWgr9a6ccuVDg_13 = 0; TM__eKG71Gy301SWgr9a6ccuVDg_13 < 107; TM__eKG71Gy301SWgr9a6ccuVDg_13++) {
TM__eKG71Gy301SWgr9a6ccuVDg_0[TM__eKG71Gy301SWgr9a6ccuVDg_13+37].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[TM__eKG71Gy301SWgr9a6ccuVDg_13+37].offset = TM__eKG71Gy301SWgr9a6ccuVDg_13;
TM__eKG71Gy301SWgr9a6ccuVDg_0[TM__eKG71Gy301SWgr9a6ccuVDg_13+37].name = TM__eKG71Gy301SWgr9a6ccuVDg_12[TM__eKG71Gy301SWgr9a6ccuVDg_13];
TM__eKG71Gy301SWgr9a6ccuVDg_11_107[TM__eKG71Gy301SWgr9a6ccuVDg_13] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[TM__eKG71Gy301SWgr9a6ccuVDg_13+37];
}
TM__eKG71Gy301SWgr9a6ccuVDg_0[144].len = 107; TM__eKG71Gy301SWgr9a6ccuVDg_0[144].kind = 2; TM__eKG71Gy301SWgr9a6ccuVDg_0[144].sons = &TM__eKG71Gy301SWgr9a6ccuVDg_11_107[0];
NTItmsgkind__rb52wmU1YxCKdMrEGfD9boA_.node = &TM__eKG71Gy301SWgr9a6ccuVDg_0[144];
NTItnotekinds__w2aCBEMcLy7t2KQe9caB9aBw_.size = sizeof(tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA);
NTItnotekinds__w2aCBEMcLy7t2KQe9caB9aBw_.align = NIM_ALIGNOF(tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA);
NTItnotekinds__w2aCBEMcLy7t2KQe9caB9aBw_.kind = 19;
NTItnotekinds__w2aCBEMcLy7t2KQe9caB9aBw_.base = (&NTItmsgkind__rb52wmU1YxCKdMrEGfD9boA_);
NTItnotekinds__w2aCBEMcLy7t2KQe9caB9aBw_.flags = 3;
TM__eKG71Gy301SWgr9a6ccuVDg_0[145].len = 17; TM__eKG71Gy301SWgr9a6ccuVDg_0[145].kind = 0;
NTItnotekinds__w2aCBEMcLy7t2KQe9caB9aBw_.node = &TM__eKG71Gy301SWgr9a6ccuVDg_0[145];
NTItmsgkind__J0cVyqzpFKvufCivtQUgHQ_.size = sizeof(tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ);
NTItmsgkind__J0cVyqzpFKvufCivtQUgHQ_.align = NIM_ALIGNOF(tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ);
NTItmsgkind__J0cVyqzpFKvufCivtQUgHQ_.kind = 14;
NTItmsgkind__J0cVyqzpFKvufCivtQUgHQ_.base = 0;
NTItmsgkind__J0cVyqzpFKvufCivtQUgHQ_.flags = 3;
for (TM__eKG71Gy301SWgr9a6ccuVDg_17 = 0; TM__eKG71Gy301SWgr9a6ccuVDg_17 < 107; TM__eKG71Gy301SWgr9a6ccuVDg_17++) {
TM__eKG71Gy301SWgr9a6ccuVDg_0[TM__eKG71Gy301SWgr9a6ccuVDg_17+146].kind = 1;
TM__eKG71Gy301SWgr9a6ccuVDg_0[TM__eKG71Gy301SWgr9a6ccuVDg_17+146].offset = TM__eKG71Gy301SWgr9a6ccuVDg_17;
TM__eKG71Gy301SWgr9a6ccuVDg_0[TM__eKG71Gy301SWgr9a6ccuVDg_17+146].name = TM__eKG71Gy301SWgr9a6ccuVDg_16[TM__eKG71Gy301SWgr9a6ccuVDg_17];
TM__eKG71Gy301SWgr9a6ccuVDg_15_107[TM__eKG71Gy301SWgr9a6ccuVDg_17] = &TM__eKG71Gy301SWgr9a6ccuVDg_0[TM__eKG71Gy301SWgr9a6ccuVDg_17+146];
}
TM__eKG71Gy301SWgr9a6ccuVDg_0[253].len = 107; TM__eKG71Gy301SWgr9a6ccuVDg_0[253].kind = 2; TM__eKG71Gy301SWgr9a6ccuVDg_0[253].sons = &TM__eKG71Gy301SWgr9a6ccuVDg_15_107[0];
NTItmsgkind__J0cVyqzpFKvufCivtQUgHQ_.node = &TM__eKG71Gy301SWgr9a6ccuVDg_0[253];
NTIerecoverableerror__aRVEU9aWMU9b9a9baYZqUd3t9cA_.size = sizeof(tyObject_ERecoverableError__aRVEU9aWMU9b9a9baYZqUd3t9cA);
NTIerecoverableerror__aRVEU9aWMU9b9a9baYZqUd3t9cA_.align = NIM_ALIGNOF(tyObject_ERecoverableError__aRVEU9aWMU9b9a9baYZqUd3t9cA);
NTIerecoverableerror__aRVEU9aWMU9b9a9baYZqUd3t9cA_.kind = 17;
NTIerecoverableerror__aRVEU9aWMU9b9a9baYZqUd3t9cA_.base = (&NTIvalueerror__5lcTdgqMq62cNGRwBb0thA_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[254].len = 0; TM__eKG71Gy301SWgr9a6ccuVDg_0[254].kind = 2;
NTIerecoverableerror__aRVEU9aWMU9b9a9baYZqUd3t9cA_.node = &TM__eKG71Gy301SWgr9a6ccuVDg_0[254];
NTIreferecoverableerror__ZxmpRAoGpPEQ4O9aAddG2FQ_.size = sizeof(tyObject_ERecoverableError__aRVEU9aWMU9b9a9baYZqUd3t9cA*);
NTIreferecoverableerror__ZxmpRAoGpPEQ4O9aAddG2FQ_.align = NIM_ALIGNOF(tyObject_ERecoverableError__aRVEU9aWMU9b9a9baYZqUd3t9cA*);
NTIreferecoverableerror__ZxmpRAoGpPEQ4O9aAddG2FQ_.kind = 22;
NTIreferecoverableerror__ZxmpRAoGpPEQ4O9aAddG2FQ_.base = (&NTIerecoverableerror__aRVEU9aWMU9b9a9baYZqUd3t9cA_);
NTIreferecoverableerror__ZxmpRAoGpPEQ4O9aAddG2FQ_.marker = Marker_tyRef__ZxmpRAoGpPEQ4O9aAddG2FQ;
NTIesuggestdone__0sxcG9bses4KEF5Ub8L9ae1Q_.size = sizeof(tyObject_ESuggestDone__0sxcG9bses4KEF5Ub8L9ae1Q);
NTIesuggestdone__0sxcG9bses4KEF5Ub8L9ae1Q_.align = NIM_ALIGNOF(tyObject_ESuggestDone__0sxcG9bses4KEF5Ub8L9ae1Q);
NTIesuggestdone__0sxcG9bses4KEF5Ub8L9ae1Q_.kind = 17;
NTIesuggestdone__0sxcG9bses4KEF5Ub8L9ae1Q_.base = (&NTIvalueerror__5lcTdgqMq62cNGRwBb0thA_);
TM__eKG71Gy301SWgr9a6ccuVDg_0[255].len = 0; TM__eKG71Gy301SWgr9a6ccuVDg_0[255].kind = 2;
NTIesuggestdone__0sxcG9bses4KEF5Ub8L9ae1Q_.node = &TM__eKG71Gy301SWgr9a6ccuVDg_0[255];
NTIrefesuggestdone__NT9aUkpr32D3T9aXH5k1dBXg_.size = sizeof(tyObject_ESuggestDone__0sxcG9bses4KEF5Ub8L9ae1Q*);
NTIrefesuggestdone__NT9aUkpr32D3T9aXH5k1dBXg_.align = NIM_ALIGNOF(tyObject_ESuggestDone__0sxcG9bses4KEF5Ub8L9ae1Q*);
NTIrefesuggestdone__NT9aUkpr32D3T9aXH5k1dBXg_.kind = 22;
NTIrefesuggestdone__NT9aUkpr32D3T9aXH5k1dBXg_.base = (&NTIesuggestdone__0sxcG9bses4KEF5Ub8L9ae1Q_);
NTIrefesuggestdone__NT9aUkpr32D3T9aXH5k1dBXg_.marker = Marker_tyRef__NT9aUkpr32D3T9aXH5k1dBXg;
}

